@@ -41,5 +41,5 @@ impl Column for Cgroup {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(String);
+    column_default!(String, false);
 }
