@@ -34,5 +34,5 @@ impl Column for Eip {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(u64);
+    column_default!(u64, true);
 }
