@@ -38,5 +38,5 @@ impl Column for SigPnd {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(u64);
+    column_default!(u64, true);
 }
