@@ -42,5 +42,5 @@ impl Column for Ssb {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(String);
+    column_default!(String, false);
 }
