@@ -35,7 +35,7 @@ impl Column for State {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(String);
+    column_default!(String, false);
 }
 
 #[cfg(target_os = "macos")]
@@ -76,7 +76,7 @@ impl Column for State {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(String);
+    column_default!(String, false);
 }
 
 #[cfg(target_os = "freebsd")]
@@ -148,5 +148,5 @@ impl Column for State {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(String);
+    column_default!(String, false);
 }
