@@ -43,5 +43,5 @@ impl Column for VmLib {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(u64);
+    column_default!(u64, true);
 }
