@@ -46,5 +46,5 @@ impl Column for WorkDir {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(String);
+    column_default!(String, false);
 }
