@@ -1,13 +1,11 @@
 use crate::column::Column;
 use crate::columns::*;
 use crate::config::*;
+use crate::opt::{ArgColorMode, ArgPagerMode};
 use crate::process::collect_proc;
 use crate::style::{apply_color, apply_style, color_to_column_style};
 use crate::term_info::TermInfo;
-use crate::util::{
-    classify, find_column_kind, find_exact, find_partial, truncate, ArgColorMode, ArgPagerMode,
-    KeywordClass,
-};
+use crate::util::{classify, find_column_kind, find_exact, find_partial, truncate, KeywordClass};
 use crate::Opt;
 use anyhow::{bail, Error};
 #[cfg(not(target_os = "windows"))]
@@ -375,6 +373,12 @@ impl View {
         config: &Config,
         theme: &ConfigTheme,
     ) -> Result<(), Error> {
+        if opt.json {
+            self.term_info.use_pager = false;
+            self.display_json()?;
+            return Ok(());
+        }
+
         let use_terminal = console::user_attended();
 
         // +3 means header/unit line and next prompt
@@ -557,6 +561,33 @@ impl View {
         Ok(())
     }
 
+    fn display_json(&self) -> Result<(), Error> {
+        self.term_info.write_line("[")?;
+
+        let len_pid = self.visible_pids.len();
+        for (i, pid) in self.visible_pids.iter().enumerate() {
+            let mut line = "{".to_string();
+            let len_column = self.columns.len();
+            for (j, c) in self.columns.iter().enumerate() {
+                if c.visible {
+                    let text = c.column.display_json(*pid);
+                    line.push_str(&text);
+                    if j != len_column - 1 {
+                        line.push_str(", ");
+                    }
+                }
+            }
+            line.push('}');
+            if i != len_pid - 1 {
+                line.push(',');
+            }
+            self.term_info.write_line(&line)?;
+        }
+
+        self.term_info.write_line("]")?;
+        Ok(())
+    }
+
     fn get_sort_info(opt: &Opt, config: &Config, cols: &[ColumnInfo]) -> SortInfo {
         let (mut sort_idx, sort_order) = match (&opt.sorta, &opt.sortd) {
             (Some(sort), _) | (_, Some(sort)) => {
